@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2008, 2009, 2010 Net-ng.
+# Copyright (c) 2008-2012 Net-ng.
 # All rights reserved.
 #
 # This software is licensed under the BSD License, as described in
@@ -18,4 +18,4 @@ Entity = declarative.declarative_base(metadata=__metadata__)
 # ---------------------------------------------------------------------------
 
 def populate2():
-    session.add(GalleryData(name=u'MyGallery'))
+    database.session.add(GalleryData(name=u'MyGallery'))
