@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2008, 2009, 2010 Net-ng.
+# Copyright (c) 2008-2012 Net-ng.
 # All rights reserved.
 #
 # This software is licensed under the BSD License, as described in
@@ -22,7 +22,7 @@ photo_table = Table(
                     Column('img', BLOB),
                     Column('thumbnail', BLOB),
                     Column('size', Integer),
-                    
+
                     Column('gallery_id', Unicode(40), ForeignKey('gallery.name'))
                    )
 
@@ -37,4 +37,4 @@ mapper(Gallery, gallery_table, properties={ 'photos' : relation(Photo, backref='
 # ---------------------------------------------------------------------------
 
 def populate():
-    session.add(Gallery(name=u'MyGallery'))
+    database.session.add(Gallery(name=u'MyGallery'))
