@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2008, 2009, 2010 Net-ng.
+# Copyright (c) 2008-2012 Net-ng.
 # All rights reserved.
 #
 # This software is licensed under the BSD License, as described in
@@ -32,7 +32,7 @@ class Login:
 @presentation.render_for(Login)
 def render(self, h, binding, *args):
     user = security.get_user()
-    
+
     if not user:
         html = h.form(
                       'Login: ', h.input(name='__ac_name'), ' ',
@@ -44,7 +44,7 @@ def render(self, h, binding, *args):
                 'Welcome ', h.b(user.id), h.br,
                 h.a('logout').action(lambda: security.get_manager().logout())
                )
-        
+
     return html
 
 # ---------------------------------------------------------------------------
@@ -67,12 +67,12 @@ def render(self, h, comp, *args):
         if node.tag == 'wiki':
             a = h.a(node.text, href='page/'+node.text).action(lambda title=unicode(node.text): comp.answer(title))
             node.replace(a)
-    
+
     h << html
-    
+
     if security.has_permissions('wiki.editor', self):
         h << h.a('Edit this page', href='page/'+self.pagename).action(lambda: comp.call(PageEditor(comp())))
-        
+
     return h.root
 
 # The meta data view now also displays the creator's name
@@ -121,7 +121,7 @@ def render(self, h, *args):
 
 class Wiki(object):
     def __init__(self):
-        self.login = component.Component(Login())        
+        self.login = component.Component(Login())
         self.content = component.Component(None)
         self.content.on_answer(self.goto)
 
@@ -131,7 +131,7 @@ class Wiki(object):
         page = query(Page).get(title)
         if page is None:
             Page(title, '')
-            session.add(Page)
+            database.session.add(Page)
 
         self.content.becomes(page)
 
@@ -140,7 +140,7 @@ def render(self, h, comp, *args):
     h.head.css('main_css', '''
     .document:first-letter { font-size:2em }
     .meta { float:right; width: 10em; border: 1px dashed gray;padding: 1em; margin: 1em; }
-    .login { font-size:0.75em; }    
+    .login { font-size:0.75em; }
     ''')
 
     with h.div(class_='login'):
@@ -153,7 +153,7 @@ def render(self, h, comp, *args):
 
     if security.has_permissions('wiki.admin', self):
         h << 'View the ' << h.a('complete list of pages', href='all').action(lambda: self.goto(comp.call(self, model='all')))
-    
+
     return h.root
 
 @presentation.render_for(Wiki, model='all')
@@ -171,13 +171,13 @@ def render(self, h, comp, *args):
 @presentation.init_for(Wiki, "(len(url) == 2) and (url[0] == 'page')")
 def init(self, url, *args):
     title = url[1]
-    
+
     page = query(Page).get(title)
     if page is None:
         raise presentation.HTTPNotFound()
 
     self.goto(title)
-    
+
 @presentation.init_for(Wiki, "len(url) and (url[0] == 'all')")
 def init(self, url, comp, *args):
     component.call_wrapper(lambda: self.goto(comp.call(self, model='all')))
@@ -194,7 +194,7 @@ class User(common.User):
     def __init__(self, id, roles=()):
         super(User, self).__init__(id)
         self.roles = flatten(roles)
-        
+
     def has_permission(self, permission):
         return permission in self.roles
 
@@ -206,17 +206,17 @@ from nagare.security import form_auth
 class Authentication(form_auth.Authentication):
     def get_password(self, username):
         return username
-    
+
     def _create_user(self, username):
         if username is None:
             return None
-        
+
         if (username == 'john') or (username == 'guest'):
             return User(username, editor_role)
-        
+
         if username == 'admin':
             return User(username, admin_role)
-        
+
         return User(username)
 
 
@@ -239,7 +239,7 @@ class Rules(common.Rules):
         creator = page.creator
         if user.has_permission(perm) and (perm != 'wiki.editor' or (creator is None) or (creator == user.id)):
             return True
-        
+
         return common.Denial()
 
 
@@ -263,9 +263,9 @@ Mapper(Page, wikialchemy.page_data)
 
 def populate():
     page = Page(u'FrontPage', u'Welcome to my *WikiWiki* !', u'admin')
-    session.add(page)
+    database.session.add(page)
 
     page = Page(u'WikiWiki', u'On this *WikiWiki*, the page contents can be '
                  'written in `Restructured Text <http://docutils.sourceforge.net/rst.html>`_',
                  u'john')
-    session.add(page)
+    database.session.add(page)
